import 'package:flutter/material.dart';
import 'package:walk_2_school/pages/rewards_page.dart';
import 'package:walk_2_school/pages/statistics_page.dart';
import 'standardized_widgets.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'pages/login_page.dart';
import 'pages/home_page.dart';
import 'pages/settings_page.dart';
import 'main.dart';
import 'pages/whos_walking_page.dart';

Widget bottomNavBar(BuildContext context, String pageName, bool isGreyed) {
  return !isGreyed
      ? Container(
          color: StandardizedWidgets.green,
          child: SizedBox(
            height: 65,
            width: MediaQuery.of(context).size.width,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              children: [
                //bottom nav items
                Column(
                  children: [
                    StandardizedWidgets().spacer(height: 5),
                    SizedBox(
                      height: 35,
                      child: IconButton(
                        color: Colors.white,
                        icon: const Icon(Icons.home_filled),
                        onPressed: () {
                          // if we are already on the home page, do nothing
                          if (pageName == 'home') {
                            return;
                          }
                          Navigator.pop(
                            context,
                            MaterialPageRoute(builder: (context) => HomePage()),
                            //(Route<dynamic> route) => false,
                          );
                        },
                      ),
                    ),
                    Text(
                      'Home',
                      style: GoogleFonts.montserrat(
                        fontSize: 12,
                        color: Colors.white,
                        fontWeight: FontWeight.w600,
                      ),
                    )
                  ],
                ),

                Column(
                  children: [
                    StandardizedWidgets().spacer(height: 5),
                    SizedBox(
                      height: 35,
                      child: IconButton(
                        color: Colors.white,
                        icon: const Icon(Icons.star_border),
                        onPressed: () {
                          //navigate to rewards
                          if (pageName == 'rewards') {
                            return;
                          } else if (pageName == 'home') {
                            Navigator.push(
                              context,
                              MaterialPageRoute(
                                  builder: (context) => const RewardsPage()),
                              // (Route<dynamic> route) => false,
                            );
                          } else {
                            Navigator.pushReplacement(
                              context,
                              MaterialPageRoute(
                                  builder: (context) => const RewardsPage()),
                              // (Route<dynamic> route) => false,
                            );
                          }
                        },
                      ),
                    ),
                    Text(
                      'Rewards',
                      style: GoogleFonts.montserrat(
                        fontSize: 12,
                        color: Colors.white,
                        fontWeight: FontWeight.w600,
                      ),
                    )
                  ],
                ),
                Column(
                  children: [
                    StandardizedWidgets().spacer(height: 5),
                    SizedBox(
                      height: 35,
                      child: IconButton(
                        color: Colors.white,
                        icon: const Icon(Icons.settings),
                        onPressed: () {
                          //navigate to settings
                          if (pageName == 'settings') {
                            return;
                          } else if (pageName == 'home') {
                            Navigator.push(
                              context,
                              MaterialPageRoute(
                                builder: (context) => SettingsPage(),
                              ),
                            );
                          } else {
                            Navigator.pushReplacement(
                              context,
                              MaterialPageRoute(
                                builder: (context) => SettingsPage(),
                              ),
                            );
                          }
                        },
                      ),
                    ),
                    Text(
                      'Settings',
                      style: GoogleFonts.montserrat(
                        fontSize: 12,
                        color: Colors.white,
                        fontWeight: FontWeight.w600,
                      ),
                    )
                  ],
                ),
                Column(
                  children: [
                    StandardizedWidgets().spacer(height: 5),
                    SizedBox(
                      height: 35,
                      child: IconButton(
                        color: Colors.white,
                        icon: const Icon(Icons.logout),
                        onPressed: () {
                          // logout
                          showDialog(
                            context: context,
                            builder: (BuildContext context) {
                              return AlertDialog(
                                shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(20),
                                ),
                                title: Text(
                                  'Logout',
                                  style: GoogleFonts.montserrat(
                                    fontSize: 25,
                                    fontWeight: FontWeight.w700,
                                    color: Colors.black,
                                  ),
                                ),
                                content: StandardizedWidgets().subscriptText(
                                    'Are you sure you want to log out?'),
                                actions: [
                                  ElevatedButton(
                                    style: ButtonStyle(
                                        backgroundColor:
                                            MaterialStateProperty.all<Color>(
                                                Colors.grey),
                                        shape: MaterialStateProperty.all<
                                                OutlinedBorder>(
                                            RoundedRectangleBorder(
                                                borderRadius:
                                                    BorderRadius.circular(
                                                        15)))),
                                    onPressed: () => Navigator.pop(context),
                                    child: StandardizedWidgets()
                                        .subscriptText('Cancel'),
                                  ),
                                  ElevatedButton(
                                    style: ButtonStyle(
                                        backgroundColor:
                                            MaterialStateProperty.all<Color>(
                                                StandardizedWidgets.green),
                                        shape: MaterialStateProperty.all<
                                                OutlinedBorder>(
                                            RoundedRectangleBorder(
                                                borderRadius:
                                                    BorderRadius.circular(
                                                        15)))),
                                    onPressed: () async {
                                      final prefs =
                                          await SharedPreferences.getInstance();
                                      await prefs.setBool('isLoggedIn', false);
                                      await prefs.remove('username');
                                      Navigator.pushReplacement(
                                          navigatorKey.currentContext!,
                                          MaterialPageRoute(
                                              builder: (_) =>
                                                  const LoginPage()));
                                    },
                                    child: StandardizedWidgets()
                                        .subscriptText('Logout'),
                                  ),
                                ],
                              );
                            },
                          );
                        },
                      ),
                    ),
                    Text(
                      'Log Out',
                      style: GoogleFonts.montserrat(
                        fontSize: 12,
                        color: Colors.white,
                        fontWeight: FontWeight.w600,
                      ),
                    )
                  ],
                ),
              ],
            ),
          ),
        )
      : Container(
          color: StandardizedWidgets.green,
          child: SizedBox(
            height: 65,
            width: MediaQuery.of(context).size.width,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              children: [
                //bottom nav items
                Opacity(
                  opacity: .5,
                  child: Column(
                    children: [
                      StandardizedWidgets().spacer(height: 5),
                      SizedBox(
                        height: 35,
                        child: IconButton(
                          color: Colors.white,
                          icon: const Icon(Icons.home_filled),
                          onPressed: () {
                            // if we are already on the home page, do nothing
                            StandardizedWidgets().basicAppDialog(
                                context,
                                'Navigation Not Available',
                                'You cannot access these pages while you are walking! Please pay attention or end your walk!',
                                'Exit');
                          },
                        ),
                      ),
                      Text(
                        'Home',
                        style: GoogleFonts.montserrat(
                          fontSize: 12,
                          color: Colors.white,
                          fontWeight: FontWeight.w600,
                        ),
                      )
                    ],
                  ),
                ),

                Opacity(
                  opacity: .5,
                  child: Column(
                    children: [
                      StandardizedWidgets().spacer(height: 5),
                      SizedBox(
                        height: 35,
                        child: IconButton(
                          color: Colors.white,
                          icon: const Icon(Icons.star_border),
                          onPressed: () {
                            //navigate to rewards
                            StandardizedWidgets().basicAppDialog(
                                context,
                                'Navigation Not Available',
                                'You cannot access these pages while you are walking! Please pay attention or end your walk!',
                                'Exit');
                          },
                        ),
                      ),
                      Text(
                        'Rewards',
                        style: GoogleFonts.montserrat(
                          fontSize: 12,
                          color: Colors.white,
                          fontWeight: FontWeight.w600,
                        ),
                      )
                    ],
                  ),
                ),
                Opacity(
                  opacity: .5,
                  child: Column(
                    children: [
                      StandardizedWidgets().spacer(height: 5),
                      SizedBox(
                        height: 35,
                        child: IconButton(
                          color: Colors.white,
                          icon: const Icon(Icons.settings),
                          onPressed: () {
                            //navigate to settings
                            StandardizedWidgets().basicAppDialog(
                                context,
                                'Navigation Not Available',
                                'You cannot access these pages while you are walking! Please pay attention or end your walk!',
                                'Exit');
                          },
                        ),
                      ),
                      Text(
                        'Settings',
                        style: GoogleFonts.montserrat(
                          fontSize: 12,
                          color: Colors.white,
                          fontWeight: FontWeight.w600,
                        ),
                      )
                    ],
                  ),
                ),
                Opacity(
                  opacity: .5,
                  child: Column(
                    children: [
                      StandardizedWidgets().spacer(height: 5),
                      SizedBox(
                        height: 35,
                        child: IconButton(
                          color: Colors.white,
                          icon: const Icon(Icons.logout),
                          onPressed: () {
                            // logout
                            StandardizedWidgets().basicAppDialog(
                                context,
                                'Navigation Not Available',
                                'You cannot access these pages while you are walking! Please pay attention or end your walk!',
                                'Exit');
                          },
                        ),
                      ),
                      Text(
                        'Log Out',
                        style: GoogleFonts.montserrat(
                          fontSize: 12,
                          color: Colors.white,
                          fontWeight: FontWeight.w600,
                        ),
                      )
                    ],
                  ),
                ),
              ],
            ),
          ),
        );
}
