import 'dart:convert';
import 'package:http/http.dart' as http;
import 'misc.dart';

// data structure for storing current walkers data
class CurrentWalkersData {
  // includes an array of json objects with the following fields: username, isWalking
  List<Walker> currentWalkersData = [];

  // constructor
  CurrentWalkersData(this.currentWalkersData);

  // constructor to create an empty CurrentWalkersData object
  CurrentWalkersData.empty();

  // static method to get the current walkers data from the backend
  static Future<CurrentWalkersData> getCurrentWalkersDataFromBackend() async {
    // get the current walkers data from the backend
    var response = await http.get(Uri.parse('$backendUrl/get-live-walking'));
    // if the response is successful, convert the response body to a CurrentWalkersData object
    if (response.statusCode == 200) {
      return CurrentWalkersData.fromJson(response.body);
    }
    // if the response is not successful, throw an error
    else {
      throw Exception('Failed to get live walking data from backend');
    }
  }

  static CurrentWalkersData fromJson(String jsonString) {
    // Decode the JSON object into a dynamic object
    print("jsonString: $jsonString");
    Map<String, dynamic> jsonObject = jsonDecode(jsonString);
    // Convert the dynamic object to a List<Walker>
    List<Walker> walkers = (jsonObject['response'] as List)
        .map((dynamic item) => Walker.fromJson(item as Map<String, dynamic>))
        .toList();

    // Return a new CurrentWalkersData instance with the list of walkers
    return CurrentWalkersData(walkers);
  }
}

// data structure for storing walker data
class Walker {
  final String username;
  final bool isWalking;

  Walker({required this.username, required this.isWalking});

  factory Walker.fromJson(Map<String, dynamic> json) {
    return Walker(
      username: json['username'],
      isWalking: json['isWalking'],
    );
  }
}
