import 'package:flutter/material.dart';
import 'package:walk_2_school/standardized_widgets.dart';
import 'package:walk_2_school/misc.dart';
import 'package:walk_2_school/user_data.dart';
import 'package:flutter/cupertino.dart';

class RedeemedRewardsPage extends StatefulWidget {
  const RedeemedRewardsPage({super.key});

  @override
  _RedeemedRewardsPageState createState() => _RedeemedRewardsPageState();
}

class _RedeemedRewardsPageState extends State<RedeemedRewardsPage> {
  UserData _currUserData = UserData.empty();
  @override
  void initState() {
    super.initState();
    _loadUserData();
  }

  void _loadUserData() async {
    _currUserData = await UserData.retrieveLocally();
    _currUserData.checkStreakReset();
    // store the user data locally
    await _currUserData.storeLocally();
    setState(() {
      _currUserData = _currUserData;
    });
  }

  bool showAllItems = false;
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: const Color(0xFF687A3E),
        centerTitle: true,
        title: StandardizedWidgets()
            .titleText('My Rewards!', color: Colors.white, fontSize: 20),
        actions: [
          IconButton(
            onPressed: () {
              // Reload the page
              Navigator.pushReplacement(
                context,
                MaterialPageRoute(
                  builder: (BuildContext context) =>
                      const RedeemedRewardsPage(),
                ),
              );
            },
            icon: const Icon(Icons.refresh),
          ),
        ],
      ),
      body: SingleChildScrollView(
        child: Center(
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: Column(children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  Expanded(
                      child: StandardizedWidgets().titleText(
                          'Your Unclaimed Rewards!',
                          alignment: TextAlign.center)),
                ],
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  StandardizedWidgets()
                      .subscriptText('Include Fulfilled Items: ', fontSize: 20),
                  CupertinoSwitch(
                    value: showAllItems,
                    onChanged: (value) {
                      setState(() {
                        showAllItems = value;
                      });
                    },
                  ),
                ],
              ),
              Column(
                children: userRewardsList(_currUserData, showAllItems),
              )
            ]),
          ),
        ),
      ),
    );
  }

  List<Widget> userRewardsList(UserData data, bool showAllOrders) {
    List<Widget> rewards = [];
    for (int i = 0; i < data.inventory.length; i++) {
      if (!showAllOrders) {
        for (int k = 0;
            k <
                data.inventory.elementAt(i)['quantity'] -
                    data.inventory.elementAt(i)['fulfilled'];
            k++) {
          rewards.add(StandardizedWidgets().rewardCard(
              context,
              data.inventory.elementAt(i)['name'],
              double.parse(data.inventory.elementAt(i)['price'].toString()),
              data.inventory.elementAt(i)['quantity'],
              _currUserData.currPoints.toDouble(),
              data.inventory.elementAt(i)['url'],
              progressBarIsVisible: false,
              infoButtonIsVisible: false,
              quantityIsVisible: false));
        }
      } else {
        for (int j = 0; j < data.inventory.elementAt(i)['quantity']; j++) {
          rewards.add(StandardizedWidgets().rewardCard(
              context,
              data.inventory.elementAt(i)['name'],
              double.parse(data.inventory.elementAt(i)['price'].toString()),
              data.inventory.elementAt(i)['quantity'],
              _currUserData.currPoints.toDouble(),
              data.inventory.elementAt(i)['url'],
              progressBarIsVisible: false,
              infoButtonIsVisible: false,
              quantityIsVisible: false));
        }
      }
    }
    return rewards;
  }
}
