import 'dart:ffi';

import 'package:flutter/material.dart';
import 'package:percent_indicator/percent_indicator.dart';
import 'package:walk_2_school/data.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:fl_chart/fl_chart.dart';
import 'package:auto_size_text/auto_size_text.dart';
import 'package:walk_2_school/pages/leaderboard_page.dart';
import 'package:walk_2_school/pages/whos_walking_page.dart';
import 'misc.dart';

class StandardizedWidgets {
  static Color green = const Color(0xFF687A3E);
  static Color blue = const Color(0xFF8DCCCE);
  static Color background = const Color(0xFFD9D9D9);
  static Color yellow = const Color(0xFFED9B40);
  static Color purple = const Color(0xFF57467B);
  static Color red = const Color(0xFFE74C3C);

  var userPassFont = GoogleFonts.montserrat(
    fontSize: 20,
    fontWeight: FontWeight.w400,
    color: const Color(0xFFD9D9D9),
  );
  var typingFont = GoogleFonts.montserrat(
    fontSize: 20,
    fontWeight: FontWeight.w400,
    color: Colors.black,
  );
  var loginFont = GoogleFonts.montserrat(
    fontSize: 24,
    fontWeight: FontWeight.w500,
    color: Colors.white,
  );
  var yellowTextFont = GoogleFonts.montserrat(
      fontSize: 15,
      fontWeight: FontWeight.w700,
      color: const Color(0xFFED9B40),
      decoration: TextDecoration.underline);

  static setTheme(bool isDarkTheme) {
    if (isDarkTheme) {
      green = const Color(0xFF687A3E);
      blue = const Color(0xFF8DCCCE);
      background = const Color(0xFFD9D9D9);
      yellow = const Color(0xFFED9B40);
      purple = const Color(0xFF57467B);
    } else {
      green = const Color(0xFF687A3E);
      blue = const Color(0xFF8DCCCE);
      background = const Color.fromARGB(255, 20, 20, 20);
      yellow = const Color(0xFFED9B40);
      purple = const Color(0xFF57467B);
    }
  }

  Widget textFields(String inputText, TextStyle style,
      TextEditingController controller, bool obscureText) {
    return TextField(
      style: style,
      controller: controller,
      decoration: InputDecoration(
          filled: true,
          fillColor: Colors.white,
          hintText: inputText,
          enabledBorder: const OutlineInputBorder(
            borderSide: BorderSide(color: Colors.white),
            borderRadius: BorderRadius.all(Radius.circular(20)),
          ),
          focusedBorder: const OutlineInputBorder(
              borderSide: BorderSide(color: Colors.white),
              borderRadius: BorderRadius.all(Radius.circular(20)))),
      obscureText: obscureText,
    );
  }

  Widget textFormFields(
      String inputText, TextStyle style, String validator, String onSavedVal) {
    return TextFormField(
      style: style,
      decoration: InputDecoration(
          hintText: inputText,
          filled: true,
          fillColor: Colors.white,
          enabledBorder: const OutlineInputBorder(
            borderSide: BorderSide(color: Colors.white),
            borderRadius: BorderRadius.all(Radius.circular(20)),
          ),
          focusedBorder: const OutlineInputBorder(
              borderSide: BorderSide(color: Colors.white),
              borderRadius: BorderRadius.all(Radius.circular(20)))),
      validator: (value) {
        if (value == null || value.isEmpty) {
          return validator;
        }
        return null;
      },
      onSaved: (value) {
        onSavedVal = value ?? '';
      },
    );
  }

  Widget largeLogo() {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Image.asset('assets/images/Logo.png'),
        const SizedBox(
          height: 35,
        ),
        Image.asset('assets/images/Text.png'),
      ],
    );
  }

  Widget spacer({double? width, double? height}) {
    return SizedBox(height: height, width: width);
  }

  Widget titleText(String text,
      {double fontSize = 40,
      TextAlign alignment = TextAlign.left,
      Color color = Colors.black}) {
    return Text(
      text,
      textAlign: alignment,
      style: GoogleFonts.montserrat(
        fontSize: fontSize,
        fontWeight: FontWeight.w700,
        color: color,
      ),
    );
  }

  Widget subscriptText(String text,
      {Color? color,
      double fontSize = 15,
      TextAlign alignment = TextAlign.left}) {
    return Text(
      text,
      softWrap: true,
      // maxLines: 1,
      textAlign: alignment,
      style: GoogleFonts.montserrat(
        fontSize: fontSize,
        fontWeight: FontWeight.w600,
        color: color,
      ),
    );
  }

  Widget generalStyledWrapper(Widget child, Widget epl,
      {Widget? title,
      double? width,
      double? height,
      Color color = Colors.white,
      double padding = 30,
      double titleHeightRatio = 10,
      double spaceAfterTitle = 30}) {
    return Material(
      elevation: 5,
      color: color,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(20),
      ),
      child: Padding(
        padding: EdgeInsets.all(padding),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            SizedBox(
              width: width,
              height: height! / titleHeightRatio,
              child: title,
            ),
            epl,
            // Column(
            //   crossAxisAlignment: CrossAxisAlignment.start,
            //   children: intermediateChildren,
            // ),
            spacer(height: spaceAfterTitle),
            SizedBox(
              height: height,
              width: width,
              child: child,
            ),
          ],
        ),
      ),
    );
  }

  FlTitlesData getTitleData(List<Data> data,
      {String leftAxisLabel = '',
      String bottomAxisLabel = '',
      double interval = 5,
      double bottomAngle = 0,
      String unit = ''}) {
    return FlTitlesData(
        show: true,
        topTitles: AxisTitles(sideTitles: SideTitles(showTitles: false)),
        rightTitles: AxisTitles(sideTitles: SideTitles(showTitles: false)),
        bottomTitles: AxisTitles(
          axisNameWidget: subscriptText(bottomAxisLabel, fontSize: 12),
          sideTitles: SideTitles(
              showTitles: true,
              interval: interval / 5,
              getTitlesWidget: (double value, TitleMeta meta) {
                String label = data
                    .firstWhere((element) => element.id == value.toInt())
                    .name;

                return SideTitleWidget(
                  angle: bottomAngle,
                  axisSide: meta.axisSide,
                  child: Text(
                    label,
                    style: GoogleFonts.montserrat(
                        color: Colors.black,
                        fontSize: 10,
                        fontWeight: FontWeight.bold),
                  ),
                );
                //;
              }
              //interval: ymax / 5.0,
              ),
        ),
        leftTitles: AxisTitles(
          axisNameWidget: subscriptText(leftAxisLabel, fontSize: 12),
          sideTitles: SideTitles(
              interval: interval / 5,
              showTitles: true,
              getTitlesWidget: (double value, TitleMeta meta) {
                String stringVal = value
                    .toString()
                    .replaceAll(RegExp(r'^0+(?=[1-9])|\.$'), '');
                if (value > 1000) {
                  stringVal =
                      '${value.round().toString().substring(0, value.toString().length - 5)}$unit';
                }
                return SideTitleWidget(
                  axisSide: meta.axisSide,
                  child: Text(
                    stringVal,
                    maxLines: 1,
                    softWrap: false,
                    style: GoogleFonts.montserrat(
                        color: Colors.black,
                        fontSize: 9,
                        fontWeight: FontWeight.bold),
                  ),
                );
                //;
              }
              // interval: xmax / 5.0,
              ),
        ));
  }

  Widget lineChart(
      List<Color> gradient, FlTitlesData titlesData, List<FlSpot> data,
      {double chartWidth = 200, double chartHeight = 200}) {
    return LineChart(
      LineChartData(
        titlesData: titlesData,
        // backgroundColor: //Colors.white24,
        borderData: FlBorderData(
          show: false,
          border: Border.all(color: Colors.black, width: 1),
        ),
        lineBarsData: [
          LineChartBarData(
            spots: data,
            isCurved: true,
            gradient: LinearGradient(colors: gradient),
            barWidth: 5,
            belowBarData: BarAreaData(
              show: true,
              gradient: LinearGradient(
                  colors:
                      gradient.map((color) => color.withOpacity(0.3)).toList()),
            ),
          ),
        ],
      ),
    );
  }

  Widget barChart(List<Color> gradient, FlTitlesData titlesData,
      List<BarChartGroupData> data,
      {double chartWidth = 200, double chartHeight = 200}) {
    return BarChart(
      BarChartData(
          titlesData: titlesData,
          borderData: FlBorderData(
            show: false,
            border: Border.all(color: Colors.black, width: 1),
          ),
          barGroups: data),
    );
  }

  Widget rewardCard(BuildContext context, String rewardName, double price,
      int quantity, double userPoints, String imageURL,
      {bool progressBarIsVisible = true,
      bool infoButtonIsVisible = true,
      bool quantityIsVisible = true}) {
    double width = MediaQuery.of(context).size.width;
    return Card(
      elevation: 5,
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(20)),
      child: SizedBox(
        width: width,
        //height: 200,
        child: IntrinsicHeight(
          child: Padding(
            padding: const EdgeInsets.all(8.0),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                ClipRRect(
                  borderRadius: BorderRadius.circular(20),
                  child: Image.network(
                    imageURL,
                    width: 60,
                    height: 60,
                  ),
                ),
                spacer(width: 10),
                Expanded(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Row(
                        children: [
                          Expanded(child: titleText(rewardName, fontSize: 25)),
                          spacer(width: 10),
                          Visibility(
                            visible: infoButtonIsVisible,
                            child: GestureDetector(
                              child: const Icon(Icons.info_outline),
                              onTap: () {
                                showDialog(
                                    context: context,
                                    builder: (BuildContext context) {
                                      return AlertDialog(
                                        title: titleText('Item Info',
                                            fontSize: 25),
                                        content: subscriptText(
                                            'If you want to redeem the $rewardName just click on the related card and accept the pop-up! Once the item is redeemed it will be added to your redemptions catalog.'),
                                      );
                                    });
                              },
                            ),
                          ),
                        ],
                      ),
                      Row(
                        children: [
                          subscriptText('Cost: ${price.round().toString()} pts',
                              alignment: TextAlign.left),
                          spacer(width: 10),
                          Visibility(
                            visible: quantityIsVisible,
                            child: subscriptText('Quantity: $quantity',
                                alignment: TextAlign.left),
                          ),
                        ],
                      ),
                      spacer(height: 10),
                      Visibility(
                        visible: progressBarIsVisible,
                        child: LinearPercentIndicator(
                          animation: true,
                          animateFromLastPercent: true,
                          padding: const EdgeInsets.all(0),
                          progressColor: yellow,
                          width: width / 1.45,
                          lineHeight: 15,
                          center: subscriptText(
                              '${userPoints > price ? 'Redeem me!' : '${price.toInt() - userPoints.toInt()} points remaining'} ',
                              fontSize: 10),
                          barRadius: const Radius.circular(20),
                          percent: userPoints > price ? 1 : userPoints / price,
                        ),
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget currentWalkerCard(
      bool isWalking, String userName, double iconWidth, double height) {
    String email = userName;
    String username = email.split("@")[0];
    return Card(
      elevation: 5,
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(20)),
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: SizedBox(
          height: height / 15,
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            children: [
              Padding(
                  padding: const EdgeInsets.all(6),
                  child: isWalking
                      ? Image.asset(
                          'assets/images/Logo.png',
                          width: iconWidth / 7,
                          color: green,
                        )
                      : SizedBox(
                          width: iconWidth / 7,
                          child: const FittedBox(
                            fit: BoxFit.fitHeight,
                            child: Icon(
                              Icons.man,

                              // size: 50,
                              color: Color(0xFFED9B40),
                            ),
                          ),
                        )),
              SizedBox(
                width: iconWidth / 1.5,
                child: FittedBox(
                  fit: BoxFit.contain,
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.start,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      titleText(username, fontSize: 30),
                      isWalking
                          ? subscriptText('I\'m walking!')
                          : subscriptText('I\'m not walking.')
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  basicAppDialog(
      BuildContext context, String title, String content, String buttonText) {
    return showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(20),
          ),
          title: Text(
            title,
            style: GoogleFonts.montserrat(
              fontSize: 25,
              fontWeight: FontWeight.w700,
              color: Colors.black,
            ),
          ),
          content: StandardizedWidgets().subscriptText(content),
          actions: [
            ElevatedButton(
              style: ButtonStyle(
                  backgroundColor: MaterialStateProperty.all<Color>(
                      StandardizedWidgets.green),
                  shape: MaterialStateProperty.all<OutlinedBorder>(
                      RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(15)))),
              onPressed: () => Navigator.pop(context),
              child: StandardizedWidgets().subscriptText(buttonText),
            ),
          ],
        );
      },
    );
  }

  confirmDialog(
    BuildContext context,
    String title,
    String content,
    String confirmButtonText,
    String cancelButtonText,
    Function onConfirm,
  ) {
    return showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(20),
          ),
          title: Text(
            title,
            style: GoogleFonts.montserrat(
              fontSize: 25,
              fontWeight: FontWeight.w700,
              color: Colors.black,
            ),
          ),
          content: subscriptText(content),
          actions: [
            ElevatedButton(
              style: ButtonStyle(
                  backgroundColor: MaterialStateProperty.all<Color>(green),
                  shape: MaterialStateProperty.all<OutlinedBorder>(
                      RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(20)))),
              onPressed: () {
                Navigator.pop(context);
                onConfirm();
              },
              child: subscriptText(confirmButtonText),
            ),
            ElevatedButton(
              style: ButtonStyle(
                  backgroundColor: MaterialStateProperty.all<Color>(green),
                  shape: MaterialStateProperty.all<OutlinedBorder>(
                      RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(20)))),
              onPressed: () => Navigator.pop(context),
              child: subscriptText(cancelButtonText),
            ),
          ],
        );
      },
    );
  }

  AppBar appBar(
    BuildContext context,
    String pageName,
    bool usePageName,
  ) {
    return AppBar(
      backgroundColor: const Color(0xFF687A3E),
      centerTitle: true,
      title: !usePageName
          ? Text(
              getHelloMessage(),
              style: const TextStyle(
                fontFamily: 'Montserrat',
                fontWeight: FontWeight.bold,
              ),
            )
          : titleText(pageName, fontSize: 20, color: Colors.white),
      actions: [
        IconButton(
          color: Colors.white,
          icon: const Icon(Icons.supervised_user_circle),
          onPressed: () {
            //navigate to statistics
            if (pageName == 'stats') {
              return;
            } else if (pageName == 'home') {
              Navigator.push(
                context,
                MaterialPageRoute(builder: (context) => WhosWalkingPage()),
                // (Route<dynamic> route) => false,
              );
            } else {
              Navigator.pushReplacement(
                context,
                MaterialPageRoute(builder: (context) => WhosWalkingPage()),
                // (Route<dynamic> route) => false,
              );
            }
          },
        ),
        IconButton(
          icon: const Icon(
            Icons.leaderboard,
            color: Colors.white,
          ),
          onPressed: () {
            // swap to leaderboard page
            Navigator.push(
              context,
              MaterialPageRoute(
                builder: (context) => const LeaderboardPage(),
              ),
            );
          },
        ),
      ],
    );
  }
}
